// python wrapper for vtkReconstructFromMoments
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkReconstructFromMoments.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkReconstructFromMoments(PyObject *dict); }
extern "C" { PyObject *PyvtkReconstructFromMoments_ClassNew(); }

#ifndef DECLARED_PyvtkDataSetAlgorithm_ClassNew
extern "C" { PyObject *PyvtkDataSetAlgorithm_ClassNew(); }
#define DECLARED_PyvtkDataSetAlgorithm_ClassNew
#endif

static const char *PyvtkReconstructFromMoments_Doc =
  "vtkReconstructFromMoments - reconstruct the underlying function from\nits moments\n\n"
  "Superclass: vtkDataSetAlgorithm\n\n"
  "vtkReconstructFromMoments is a filter that takes the momentData as\n"
  "produced by vtkComputeMoments or vtkMomentInvariants and a grid. It\n"
  "reconstructs the function from the moments, just like from the\n"
  "coefficients of a taylor series. There are in principal three\n"
  "applications.\n"
  "1. If we put in the moments of the pattern and the grid of the\n"
  "   pattern, we see what the algorithm can actually se during the\n"
  "   pattern detection.\n"
  "2. If we put in the normalized moments of the pattern and the grid of\n"
  "the pattern, we how the standard position looks like.\n"
  "3. If we put in the moments of the field and the original field data,\n"
  "we can see how well the subset of points, on which the moments were\n"
  "   computed, actually represents the field For the reconstruction, we\n"
  "need to orthonormalize the moments first. Then, we multiply the\n"
  "   coefficients with their corresponding basis function and add them\n"
  "   up.@par Thanks: Developed by Roxana Bujack at Los Alamos National\n"
  "   Laboratory.\n\n";


static PyObject *
PyvtkReconstructFromMoments_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkReconstructFromMoments::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkReconstructFromMoments::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkReconstructFromMoments *tempr = vtkReconstructFromMoments::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkReconstructFromMoments *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkReconstructFromMoments::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkReconstructFromMoments::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkReconstructFromMoments::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SetMomentsData(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetMomentsData");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  vtkDataObject *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkDataObject"))
  {
    if (ap.IsBound())
    {
      op->SetMomentsData(temp0);
    }
    else
    {
      op->vtkReconstructFromMoments::SetMomentsData(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SetMomentsConnection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetMomentsConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  vtkAlgorithmOutput *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithmOutput"))
  {
    if (ap.IsBound())
    {
      op->SetMomentsConnection(temp0);
    }
    else
    {
      op->vtkReconstructFromMoments::SetMomentsConnection(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SetGridData(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGridData");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  vtkDataObject *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkDataObject"))
  {
    if (ap.IsBound())
    {
      op->SetGridData(temp0);
    }
    else
    {
      op->vtkReconstructFromMoments::SetGridData(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SetGridConnection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGridConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  vtkAlgorithmOutput *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithmOutput"))
  {
    if (ap.IsBound())
    {
      op->SetGridConnection(temp0);
    }
    else
    {
      op->vtkReconstructFromMoments::SetGridConnection(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_SetAllowExtrapolation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAllowExtrapolation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAllowExtrapolation(temp0);
    }
    else
    {
      op->vtkReconstructFromMoments::SetAllowExtrapolation(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReconstructFromMoments_GetAllowExtrapolation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAllowExtrapolation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReconstructFromMoments *op = static_cast<vtkReconstructFromMoments *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetAllowExtrapolation() :
      op->vtkReconstructFromMoments::GetAllowExtrapolation());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkReconstructFromMoments_Methods[] = {
  {"IsTypeOf", PyvtkReconstructFromMoments_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkReconstructFromMoments_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkReconstructFromMoments_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkReconstructFromMoments\nC++: static vtkReconstructFromMoments *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkReconstructFromMoments_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkReconstructFromMoments\nC++: vtkReconstructFromMoments *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkReconstructFromMoments_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkReconstructFromMoments_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetMomentsData", PyvtkReconstructFromMoments_SetMomentsData, METH_VARARGS,
   "V.SetMomentsData(vtkDataObject)\nC++: void SetMomentsData(vtkDataObject *input)\n\nstandard pipeline input for port 1 This is the data as produced\nby vtkComputeMoments or vtkMomentInvariants.\n"},
  {"SetMomentsConnection", PyvtkReconstructFromMoments_SetMomentsConnection, METH_VARARGS,
   "V.SetMomentsConnection(vtkAlgorithmOutput)\nC++: void SetMomentsConnection(vtkAlgorithmOutput *algOutput)\n\nstandard pipeline input for port 1 This is the data as produced\nby vtkComputeMoments or vtkMomentInvariants.\n"},
  {"SetGridData", PyvtkReconstructFromMoments_SetGridData, METH_VARARGS,
   "V.SetGridData(vtkDataObject)\nC++: void SetGridData(vtkDataObject *input)\n\nstandard pipeline input for port 1 This input steers the topology\nof the reconstructed field.\n"},
  {"SetGridConnection", PyvtkReconstructFromMoments_SetGridConnection, METH_VARARGS,
   "V.SetGridConnection(vtkAlgorithmOutput)\nC++: void SetGridConnection(vtkAlgorithmOutput *algOutput)\n\nstandard pipeline input for port 1 This input steers the topology\nof the reconstructed field.\n"},
  {"SetAllowExtrapolation", PyvtkReconstructFromMoments_SetAllowExtrapolation, METH_VARARGS,
   "V.SetAllowExtrapolation(bool)\nC++: virtual void SetAllowExtrapolation(bool _arg)\n\nSet/Get The reconstruction function returns zero if the point is\noutside the integration radius of a vertex iff AllowExtrapolation\nis false\n"},
  {"GetAllowExtrapolation", PyvtkReconstructFromMoments_GetAllowExtrapolation, METH_VARARGS,
   "V.GetAllowExtrapolation() -> bool\nC++: virtual bool GetAllowExtrapolation()\n\nSet/Get The reconstruction function returns zero if the point is\noutside the integration radius of a vertex iff AllowExtrapolation\nis false\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkReconstructFromMoments_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "MomentInvariants.vtkReconstructFromMoments", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkReconstructFromMoments_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkReconstructFromMoments_StaticNew()
{
  return vtkReconstructFromMoments::New();
}

PyObject *PyvtkReconstructFromMoments_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkReconstructFromMoments_Type, PyvtkReconstructFromMoments_Methods,
    "vtkReconstructFromMoments",
 &PyvtkReconstructFromMoments_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkDataSetAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkReconstructFromMoments(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkReconstructFromMoments_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkReconstructFromMoments", o) != 0)
  {
    Py_DECREF(o);
  }

}

