// python wrapper for vtkFrenetSerretFrame
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkFrenetSerretFrame.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkFrenetSerretFrame(PyObject *dict); }
extern "C" { PyObject *PyvtkFrenetSerretFrame_ClassNew(); }

#ifndef DECLARED_PyvtkPolyDataAlgorithm_ClassNew
extern "C" { PyObject *PyvtkPolyDataAlgorithm_ClassNew(); }
#define DECLARED_PyvtkPolyDataAlgorithm_ClassNew
#endif

static const char *PyvtkFrenetSerretFrame_Doc =
  "vtkFrenetSerretFrame - Compute tangent and normal vectors to a\npolyline\n\n"
  "Superclass: vtkPolyDataAlgorithm\n\n"
  "Given a polyline as input, this filter computes the Frenet-Serret\n"
  "frame at each point. The output contains the tangent and normal\n"
  "vectors to the curve. These vectors are appended, so that input array\n"
  "are not overwrited\\see vtkImagePathReslice for a use-case.\n\n"
  "\\todo Comment this class. (cxx)\\todo [ENH] compute the whole chart\n"
  "(B=N^T) and put it in the PointData as a tensor.\n\n"
  "\\author Jerome Velut\\date 21 jan 2010\n\n";


static PyObject *
PyvtkFrenetSerretFrame_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkFrenetSerretFrame::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkFrenetSerretFrame::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkFrenetSerretFrame *tempr = vtkFrenetSerretFrame::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkFrenetSerretFrame *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkFrenetSerretFrame::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkFrenetSerretFrame::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkFrenetSerretFrame::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_ConsistentNormalsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ConsistentNormalsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ConsistentNormalsOn();
    }
    else
    {
      op->vtkFrenetSerretFrame::ConsistentNormalsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_ConsistentNormalsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ConsistentNormalsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ConsistentNormalsOff();
    }
    else
    {
      op->vtkFrenetSerretFrame::ConsistentNormalsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_SetConsistentNormals(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetConsistentNormals");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetConsistentNormals(temp0);
    }
    else
    {
      op->vtkFrenetSerretFrame::SetConsistentNormals(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_GetConsistentNormals(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetConsistentNormals");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetConsistentNormals() :
      op->vtkFrenetSerretFrame::GetConsistentNormals());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_ComputeBinormalOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ComputeBinormalOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ComputeBinormalOn();
    }
    else
    {
      op->vtkFrenetSerretFrame::ComputeBinormalOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_ComputeBinormalOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ComputeBinormalOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ComputeBinormalOff();
    }
    else
    {
      op->vtkFrenetSerretFrame::ComputeBinormalOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_SetComputeBinormal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetComputeBinormal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetComputeBinormal(temp0);
    }
    else
    {
      op->vtkFrenetSerretFrame::SetComputeBinormal(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_GetComputeBinormal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetComputeBinormal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetComputeBinormal() :
      op->vtkFrenetSerretFrame::GetComputeBinormal());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_SetViewUp(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetViewUp");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetViewUp(temp0);
    }
    else
    {
      op->vtkFrenetSerretFrame::SetViewUp(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_GetViewUp(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetViewUp");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFrenetSerretFrame *op = static_cast<vtkFrenetSerretFrame *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetViewUp() :
      op->vtkFrenetSerretFrame::GetViewUp());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkFrenetSerretFrame_RotateVector(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "RotateVector");

  size_t size0 = ap.GetArgSize(0);
  vtkPythonArgs::Array<double> store0(2*size0);
  double *temp0 = store0.Data();
  double *save0 = (size0 == 0 ? nullptr : temp0 + size0);
  size_t size1 = ap.GetArgSize(1);
  vtkPythonArgs::Array<double> store1(size1);
  double *temp1 = store1.Data();
  double temp2;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(3) &&
      ap.GetArray(temp0, size0) &&
      ap.GetArray(temp1, size1) &&
      ap.GetValue(temp2))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    vtkFrenetSerretFrame::RotateVector(temp0, temp1, temp2);

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkFrenetSerretFrame_Methods[] = {
  {"IsTypeOf", PyvtkFrenetSerretFrame_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkFrenetSerretFrame_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkFrenetSerretFrame_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkFrenetSerretFrame\nC++: static vtkFrenetSerretFrame *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkFrenetSerretFrame_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkFrenetSerretFrame\nC++: vtkFrenetSerretFrame *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkFrenetSerretFrame_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkFrenetSerretFrame_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"ConsistentNormalsOn", PyvtkFrenetSerretFrame_ConsistentNormalsOn, METH_VARARGS,
   "V.ConsistentNormalsOn()\nC++: virtual void ConsistentNormalsOn()\n\nSet ConsistentNormals to 1 if you want your frames to be\n'smooth'. Note that in this case, the normal to the curve will\nnot represent the acceleration, ie this is no more Frenet-Serret\nchart.\n"},
  {"ConsistentNormalsOff", PyvtkFrenetSerretFrame_ConsistentNormalsOff, METH_VARARGS,
   "V.ConsistentNormalsOff()\nC++: virtual void ConsistentNormalsOff()\n\n"},
  {"SetConsistentNormals", PyvtkFrenetSerretFrame_SetConsistentNormals, METH_VARARGS,
   "V.SetConsistentNormals(int)\nC++: virtual void SetConsistentNormals(int _arg)\n\n"},
  {"GetConsistentNormals", PyvtkFrenetSerretFrame_GetConsistentNormals, METH_VARARGS,
   "V.GetConsistentNormals() -> int\nC++: virtual int GetConsistentNormals()\n\n"},
  {"ComputeBinormalOn", PyvtkFrenetSerretFrame_ComputeBinormalOn, METH_VARARGS,
   "V.ComputeBinormalOn()\nC++: virtual void ComputeBinormalOn()\n\nIf yes, computes the cross product between Tangent and Normal to\nget the binormal vector.\n"},
  {"ComputeBinormalOff", PyvtkFrenetSerretFrame_ComputeBinormalOff, METH_VARARGS,
   "V.ComputeBinormalOff()\nC++: virtual void ComputeBinormalOff()\n\n"},
  {"SetComputeBinormal", PyvtkFrenetSerretFrame_SetComputeBinormal, METH_VARARGS,
   "V.SetComputeBinormal(int)\nC++: virtual void SetComputeBinormal(int _arg)\n\n"},
  {"GetComputeBinormal", PyvtkFrenetSerretFrame_GetComputeBinormal, METH_VARARGS,
   "V.GetComputeBinormal() -> int\nC++: virtual int GetComputeBinormal()\n\n"},
  {"SetViewUp", PyvtkFrenetSerretFrame_SetViewUp, METH_VARARGS,
   "V.SetViewUp(float)\nC++: virtual void SetViewUp(double _arg)\n\nDefine the inclination of the consistent normals. Radian value.\n"},
  {"GetViewUp", PyvtkFrenetSerretFrame_GetViewUp, METH_VARARGS,
   "V.GetViewUp() -> float\nC++: virtual double GetViewUp()\n\n"},
  {"RotateVector", PyvtkFrenetSerretFrame_RotateVector, METH_VARARGS,
   "V.RotateVector([float, ...], (float, ...), float)\nC++: static void RotateVector(double *vector, const double *axis,\n    double angle)\n\nRotate a vector around an axis\n\\param [in] axis {Vector defining the axis to turn around.}\n\\param [in] angle {Rotation angle in radian.}\n\\param [out] vector {Vector to rotate. In place modification.}\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkFrenetSerretFrame_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "SplineDrivenImageSlicer.vtkFrenetSerretFrame", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkFrenetSerretFrame_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkFrenetSerretFrame_StaticNew()
{
  return vtkFrenetSerretFrame::New();
}

PyObject *PyvtkFrenetSerretFrame_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkFrenetSerretFrame_Type, PyvtkFrenetSerretFrame_Methods,
    "vtkFrenetSerretFrame",
 &PyvtkFrenetSerretFrame_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkPolyDataAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkFrenetSerretFrame(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkFrenetSerretFrame_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkFrenetSerretFrame", o) != 0)
  {
    Py_DECREF(o);
  }

}

