// python wrapper for vtkSplineDrivenImageSlicer
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkSplineDrivenImageSlicer.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkSplineDrivenImageSlicer(PyObject *dict); }
extern "C" { PyObject *PyvtkSplineDrivenImageSlicer_ClassNew(); }

#ifndef DECLARED_PyvtkImageAlgorithm_ClassNew
extern "C" { PyObject *PyvtkImageAlgorithm_ClassNew(); }
#define DECLARED_PyvtkImageAlgorithm_ClassNew
#endif

static const char *PyvtkSplineDrivenImageSlicer_Doc =
  "vtkSplineDrivenImageSlicer - Reslicing of a volume along a path\n\n"
  "Superclass: vtkImageAlgorithm\n\n"
  "Straightened Curved Planar Reformation (Stretched-CPR) builds a 2D\n"
  "image from an input path and an input volume. Each point of the path\n"
  "is considered as the center of a 2D vtkImageReslicer. Reslicers axes\n"
  "are set orthogonal to the path. Reslicers output are appended on the\n"
  "z axis. Thus the output of this filter is a volume with central XZ-\n"
  "and YZ-slices corresponding to the Straightened-CPR.\n\n"
  "Input: vtkImageData (InputConnection) and vtkPolyData\n"
  "(PathConnection) one polyline representing the path. Typically, the\n"
  "output of vtkSpline can be used as path input.\n\n"
  "\\see Kanitsar et al. \"CPR - Curved Planar Reformation\", Proc. IEEE \n"
  "Visualization, 2002, 37-44\\author Jerome Velut\\date 6 february 2011\n\n";


static PyObject *
PyvtkSplineDrivenImageSlicer_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSplineDrivenImageSlicer::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkSplineDrivenImageSlicer::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkSplineDrivenImageSlicer *tempr = vtkSplineDrivenImageSlicer::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkSplineDrivenImageSlicer *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkSplineDrivenImageSlicer::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSplineDrivenImageSlicer::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkSplineDrivenImageSlicer::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetPathConnection_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetPathConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  int temp0;
  vtkAlgorithmOutput *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetVTKObject(temp1, "vtkAlgorithmOutput"))
  {
    if (ap.IsBound())
    {
      op->SetPathConnection(temp0, temp1);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetPathConnection(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetPathConnection_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetPathConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  vtkAlgorithmOutput *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithmOutput"))
  {
    if (ap.IsBound())
    {
      op->SetPathConnection(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetPathConnection(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetPathConnection(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 2:
      return PyvtkSplineDrivenImageSlicer_SetPathConnection_s1(self, args);
    case 1:
      return PyvtkSplineDrivenImageSlicer_SetPathConnection_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetPathConnection");
  return nullptr;
}



static PyObject *
PyvtkSplineDrivenImageSlicer_GetPathConnection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetPathConnection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkAlgorithmOutput *tempr = (ap.IsBound() ?
      op->GetPathConnection() :
      op->vtkSplineDrivenImageSlicer::GetPathConnection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceExtent_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSliceExtent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  int temp0;
  int temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
  {
    if (ap.IsBound())
    {
      op->SetSliceExtent(temp0, temp1);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetSliceExtent(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceExtent_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSliceExtent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  const size_t size0 = 2;
  int temp0[2];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetSliceExtent(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetSliceExtent(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceExtent(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 2:
      return PyvtkSplineDrivenImageSlicer_SetSliceExtent_s1(self, args);
    case 1:
      return PyvtkSplineDrivenImageSlicer_SetSliceExtent_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetSliceExtent");
  return nullptr;
}



static PyObject *
PyvtkSplineDrivenImageSlicer_GetSliceExtent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSliceExtent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  size_t sizer = 2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int *tempr = (ap.IsBound() ?
      op->GetSliceExtent() :
      op->vtkSplineDrivenImageSlicer::GetSliceExtent());

    if (!ap.ErrorOccurred())
    {
      result = vtkPythonArgs::BuildTuple(tempr, sizer);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceSpacing_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSliceSpacing");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  double temp0;
  double temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
  {
    if (ap.IsBound())
    {
      op->SetSliceSpacing(temp0, temp1);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetSliceSpacing(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceSpacing_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSliceSpacing");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  const size_t size0 = 2;
  double temp0[2];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetSliceSpacing(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetSliceSpacing(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceSpacing(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 2:
      return PyvtkSplineDrivenImageSlicer_SetSliceSpacing_s1(self, args);
    case 1:
      return PyvtkSplineDrivenImageSlicer_SetSliceSpacing_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetSliceSpacing");
  return nullptr;
}



static PyObject *
PyvtkSplineDrivenImageSlicer_GetSliceSpacing(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSliceSpacing");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  size_t sizer = 2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double *tempr = (ap.IsBound() ?
      op->GetSliceSpacing() :
      op->vtkSplineDrivenImageSlicer::GetSliceSpacing());

    if (!ap.ErrorOccurred())
    {
      result = vtkPythonArgs::BuildTuple(tempr, sizer);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetSliceThickness(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSliceThickness");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetSliceThickness(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetSliceThickness(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetSliceThickness(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSliceThickness");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetSliceThickness() :
      op->vtkSplineDrivenImageSlicer::GetSliceThickness());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetOffsetPoint(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOffsetPoint");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetOffsetPoint(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetOffsetPoint(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetOffsetPoint(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetOffsetPoint");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetOffsetPoint() :
      op->vtkSplineDrivenImageSlicer::GetOffsetPoint());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetOffsetLine(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOffsetLine");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetOffsetLine(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetOffsetLine(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetOffsetLine(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetOffsetLine");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetOffsetLine() :
      op->vtkSplineDrivenImageSlicer::GetOffsetLine());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetProbeInput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetProbeInput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetProbeInput(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetProbeInput(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetProbeInput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetProbeInput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetProbeInput() :
      op->vtkSplineDrivenImageSlicer::GetProbeInput());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_ProbeInputOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ProbeInputOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ProbeInputOn();
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::ProbeInputOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_ProbeInputOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ProbeInputOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ProbeInputOff();
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::ProbeInputOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_SetIncidence(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetIncidence");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetIncidence(temp0);
    }
    else
    {
      op->vtkSplineDrivenImageSlicer::SetIncidence(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSplineDrivenImageSlicer_GetIncidence(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetIncidence");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSplineDrivenImageSlicer *op = static_cast<vtkSplineDrivenImageSlicer *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetIncidence() :
      op->vtkSplineDrivenImageSlicer::GetIncidence());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkSplineDrivenImageSlicer_Methods[] = {
  {"IsTypeOf", PyvtkSplineDrivenImageSlicer_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkSplineDrivenImageSlicer_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkSplineDrivenImageSlicer_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkSplineDrivenImageSlicer\nC++: static vtkSplineDrivenImageSlicer *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkSplineDrivenImageSlicer_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkSplineDrivenImageSlicer\nC++: vtkSplineDrivenImageSlicer *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkSplineDrivenImageSlicer_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkSplineDrivenImageSlicer_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetPathConnection", PyvtkSplineDrivenImageSlicer_SetPathConnection, METH_VARARGS,
   "V.SetPathConnection(int, vtkAlgorithmOutput)\nC++: void SetPathConnection(int id, vtkAlgorithmOutput *algOutput)\nV.SetPathConnection(vtkAlgorithmOutput)\nC++: void SetPathConnection(vtkAlgorithmOutput *algOutput)\n\nSpecify the path represented by a vtkPolyData wich contains\nPolyLines\n"},
  {"GetPathConnection", PyvtkSplineDrivenImageSlicer_GetPathConnection, METH_VARARGS,
   "V.GetPathConnection() -> vtkAlgorithmOutput\nC++: vtkAlgorithmOutput *GetPathConnection()\n\n"},
  {"SetSliceExtent", PyvtkSplineDrivenImageSlicer_SetSliceExtent, METH_VARARGS,
   "V.SetSliceExtent(int, int)\nC++: virtual void SetSliceExtent(int _arg1, int _arg2)\nV.SetSliceExtent((int, int))\nC++: void SetSliceExtent(const int _arg[2])\n\n"},
  {"GetSliceExtent", PyvtkSplineDrivenImageSlicer_GetSliceExtent, METH_VARARGS,
   "V.GetSliceExtent() -> (int, int)\nC++: virtual int *GetSliceExtent()\n\n"},
  {"SetSliceSpacing", PyvtkSplineDrivenImageSlicer_SetSliceSpacing, METH_VARARGS,
   "V.SetSliceSpacing(float, float)\nC++: virtual void SetSliceSpacing(double _arg1, double _arg2)\nV.SetSliceSpacing((float, float))\nC++: void SetSliceSpacing(const double _arg[2])\n\n"},
  {"GetSliceSpacing", PyvtkSplineDrivenImageSlicer_GetSliceSpacing, METH_VARARGS,
   "V.GetSliceSpacing() -> (float, float)\nC++: virtual double *GetSliceSpacing()\n\n"},
  {"SetSliceThickness", PyvtkSplineDrivenImageSlicer_SetSliceThickness, METH_VARARGS,
   "V.SetSliceThickness(float)\nC++: virtual void SetSliceThickness(double _arg)\n\n"},
  {"GetSliceThickness", PyvtkSplineDrivenImageSlicer_GetSliceThickness, METH_VARARGS,
   "V.GetSliceThickness() -> float\nC++: virtual double GetSliceThickness()\n\n"},
  {"SetOffsetPoint", PyvtkSplineDrivenImageSlicer_SetOffsetPoint, METH_VARARGS,
   "V.SetOffsetPoint(int)\nC++: virtual void SetOffsetPoint(vtkIdType _arg)\n\n"},
  {"GetOffsetPoint", PyvtkSplineDrivenImageSlicer_GetOffsetPoint, METH_VARARGS,
   "V.GetOffsetPoint() -> int\nC++: virtual vtkIdType GetOffsetPoint()\n\n"},
  {"SetOffsetLine", PyvtkSplineDrivenImageSlicer_SetOffsetLine, METH_VARARGS,
   "V.SetOffsetLine(int)\nC++: virtual void SetOffsetLine(vtkIdType _arg)\n\n"},
  {"GetOffsetLine", PyvtkSplineDrivenImageSlicer_GetOffsetLine, METH_VARARGS,
   "V.GetOffsetLine() -> int\nC++: virtual vtkIdType GetOffsetLine()\n\n"},
  {"SetProbeInput", PyvtkSplineDrivenImageSlicer_SetProbeInput, METH_VARARGS,
   "V.SetProbeInput(int)\nC++: virtual void SetProbeInput(vtkIdType _arg)\n\n"},
  {"GetProbeInput", PyvtkSplineDrivenImageSlicer_GetProbeInput, METH_VARARGS,
   "V.GetProbeInput() -> int\nC++: virtual vtkIdType GetProbeInput()\n\n"},
  {"ProbeInputOn", PyvtkSplineDrivenImageSlicer_ProbeInputOn, METH_VARARGS,
   "V.ProbeInputOn()\nC++: virtual void ProbeInputOn()\n\n"},
  {"ProbeInputOff", PyvtkSplineDrivenImageSlicer_ProbeInputOff, METH_VARARGS,
   "V.ProbeInputOff()\nC++: virtual void ProbeInputOff()\n\n"},
  {"SetIncidence", PyvtkSplineDrivenImageSlicer_SetIncidence, METH_VARARGS,
   "V.SetIncidence(float)\nC++: virtual void SetIncidence(double _arg)\n\n"},
  {"GetIncidence", PyvtkSplineDrivenImageSlicer_GetIncidence, METH_VARARGS,
   "V.GetIncidence() -> float\nC++: virtual double GetIncidence()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkSplineDrivenImageSlicer_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "SplineDrivenImageSlicer.vtkSplineDrivenImageSlicer", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkSplineDrivenImageSlicer_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkSplineDrivenImageSlicer_StaticNew()
{
  return vtkSplineDrivenImageSlicer::New();
}

PyObject *PyvtkSplineDrivenImageSlicer_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkSplineDrivenImageSlicer_Type, PyvtkSplineDrivenImageSlicer_Methods,
    "vtkSplineDrivenImageSlicer",
 &PyvtkSplineDrivenImageSlicer_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkImageAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkSplineDrivenImageSlicer(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkSplineDrivenImageSlicer_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkSplineDrivenImageSlicer", o) != 0)
  {
    Py_DECREF(o);
  }

}

