// python wrapper for vtkDICOMSequence
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkDICOMTag.h"
#include "vtkDICOMSequence.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkDICOMSequence(PyObject *dict); }

static const char *PyvtkDICOMSequence_Doc =
  "vtkDICOMSequence - A sequence of items according to the SQ\nrepresentation.\n\n"
  "This class is for constructing and decoding sequences. There are two\n"
  "ways that sequences can be constructed: A fixed-size sequence can be\n"
  "created and then its items filled in with the SetItem() method, or,\n"
  "you can start with an empty sequence and use AddItem() to append\n"
  "items.\n\n"
  "vtkDICOMSequence()\n"
  "explicit vtkDICOMSequence(unsigned int n)\n"
  "vtkDICOMSequence(const vtkDICOMSequence &o)\n"
  "vtkDICOMSequence(const vtkDICOMValue &o)\n";


static PyObject *
PyvtkDICOMSequence_Clear(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Clear");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    op->Clear();

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkDICOMSequence_Get_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Get");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  vtkDICOMTag *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkDICOMTag"))
  {
    const vtkDICOMValue *tempr = &op->Get(temp0, *temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(tempr, "vtkDICOMValue");
    }
  }

  Py_XDECREF(pobj1);

  return result;
}

static PyObject *
PyvtkDICOMSequence_Get_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Get");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  vtkDICOMTagPath *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkDICOMTagPath"))
  {
    const vtkDICOMValue *tempr = &op->Get(temp0, *temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(tempr, "vtkDICOMValue");
    }
  }

  Py_XDECREF(pobj1);

  return result;
}

static PyMethodDef PyvtkDICOMSequence_Get_Methods[] = {
  {nullptr, PyvtkDICOMSequence_Get_s1, METH_VARARGS,
   "@KW vtkDICOMTag"},
  {nullptr, PyvtkDICOMSequence_Get_s2, METH_VARARGS,
   "@KW vtkDICOMTagPath"},
  {nullptr, nullptr, 0, nullptr}
};

static PyObject *
PyvtkDICOMSequence_Get(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkDICOMSequence_Get_Methods;
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
  {
    case 2:
      return vtkPythonOverload::CallMethod(methods, self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "Get");
  return nullptr;
}



static PyObject *
PyvtkDICOMSequence_GetAttributeValue_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAttributeValue");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  vtkDICOMTag *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkDICOMTag"))
  {
    const vtkDICOMValue *tempr = &op->GetAttributeValue(temp0, *temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(tempr, "vtkDICOMValue");
    }
  }

  Py_XDECREF(pobj1);

  return result;
}

static PyObject *
PyvtkDICOMSequence_GetAttributeValue_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAttributeValue");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  vtkDICOMTagPath *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkDICOMTagPath"))
  {
    const vtkDICOMValue *tempr = &op->GetAttributeValue(temp0, *temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(tempr, "vtkDICOMValue");
    }
  }

  Py_XDECREF(pobj1);

  return result;
}

static PyMethodDef PyvtkDICOMSequence_GetAttributeValue_Methods[] = {
  {nullptr, PyvtkDICOMSequence_GetAttributeValue_s1, METH_VARARGS,
   "@KW vtkDICOMTag"},
  {nullptr, PyvtkDICOMSequence_GetAttributeValue_s2, METH_VARARGS,
   "@KW vtkDICOMTagPath"},
  {nullptr, nullptr, 0, nullptr}
};

static PyObject *
PyvtkDICOMSequence_GetAttributeValue(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkDICOMSequence_GetAttributeValue_Methods;
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
  {
    case 2:
      return vtkPythonOverload::CallMethod(methods, self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "GetAttributeValue");
  return nullptr;
}



static PyObject *
PyvtkDICOMSequence_AddItem(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddItem");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  vtkDICOMItem *temp0 = nullptr;
  PyObject *pobj0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkDICOMItem"))
  {
    op->AddItem(*temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  Py_XDECREF(pobj0);

  return result;
}


static PyObject *
PyvtkDICOMSequence_GetNumberOfItems(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfItems");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    size_t tempr = op->GetNumberOfItems();

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkDICOMSequence_SetItem(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetItem");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  vtkDICOMItem *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkDICOMItem"))
  {
    op->SetItem(temp0, *temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  Py_XDECREF(pobj1);

  return result;
}


static PyObject *
PyvtkDICOMSequence_GetItem(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetItem");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  size_t temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const vtkDICOMItem *tempr = &op->GetItem(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(tempr, "vtkDICOMItem");
    }
  }

  return result;
}


static PyObject *
PyvtkDICOMSequence_IsValid(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsValid");
  void *vp = ap.GetSelfSpecialPointer(self, args);
  vtkDICOMSequence *op = static_cast<vtkDICOMSequence *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = op->IsValid();

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkDICOMSequence_Methods[] = {
  {"Clear", PyvtkDICOMSequence_Clear, METH_VARARGS,
   "V.Clear()\nC++: void Clear()\n\nClear a sequence, remove its contents and make it empty.\n"},
  {"Get", PyvtkDICOMSequence_Get, METH_VARARGS,
   "V.Get(int, vtkDICOMTag) -> vtkDICOMValue\nC++: const vtkDICOMValue &Get(size_t i, vtkDICOMTag tag)\nV.Get(int, vtkDICOMTagPath) -> vtkDICOMValue\nC++: const vtkDICOMValue &Get(size_t i, const vtkDICOMTagPath &p)\n\nGet a value from an item in the sequence.\n"},
  {"GetAttributeValue", PyvtkDICOMSequence_GetAttributeValue, METH_VARARGS,
   "V.GetAttributeValue(int, vtkDICOMTag) -> vtkDICOMValue\nC++: const vtkDICOMValue &GetAttributeValue(size_t i,\n    vtkDICOMTag tag)\nV.GetAttributeValue(int, vtkDICOMTagPath) -> vtkDICOMValue\nC++: const vtkDICOMValue &GetAttributeValue(size_t i,\n    const vtkDICOMTagPath &p)\n\nGet a value from an item in the sequence.\n"},
  {"AddItem", PyvtkDICOMSequence_AddItem, METH_VARARGS,
   "V.AddItem(vtkDICOMItem)\nC++: void AddItem(const vtkDICOMItem &item)\n\nAdd an item to the sequence.\n\nAfter calling this method, GetNumberOfItems() will report the\nnumber of items in the sequence, but GetVL() will return the\nspecial value 0xffffffff to indicate that this is a delimited\nsequence rather than a fixed-size sequence.\n"},
  {"GetNumberOfItems", PyvtkDICOMSequence_GetNumberOfItems, METH_VARARGS,
   "V.GetNumberOfItems() -> int\nC++: size_t GetNumberOfItems()\n\nGet the number of items in the sequence.\n"},
  {"SetItem", PyvtkDICOMSequence_SetItem, METH_VARARGS,
   "V.SetItem(int, vtkDICOMItem)\nC++: void SetItem(size_t i, const vtkDICOMItem &item)\n\nSet an item in the sequence.\n\nThis method can only be used if space as been allocated within\nthe sequence by specifying a size when calling the constructor.\n"},
  {"GetItem", PyvtkDICOMSequence_GetItem, METH_VARARGS,
   "V.GetItem(int) -> vtkDICOMItem\nC++: const vtkDICOMItem &GetItem(size_t i)\n\nGet an item from the sequence.\n"},
  {"IsValid", PyvtkDICOMSequence_IsValid, METH_VARARGS,
   "V.IsValid() -> bool\nC++: bool IsValid()\n\nCheck that the sequence was constructed from a valid value.\n"},
  {nullptr, nullptr, 0, nullptr}
};


static PyObject *
PyvtkDICOMSequence_vtkDICOMSequence_s1(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkDICOMSequence");

  PyObject *result = nullptr;

  if (ap.CheckArgCount(0))
  {
    vtkDICOMSequence *op = new vtkDICOMSequence();

    result = PyVTKSpecialObject_New("vtkDICOMSequence", op);
  }

  return result;
}

static PyObject *
PyvtkDICOMSequence_vtkDICOMSequence_s2(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkDICOMSequence");

  unsigned int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    vtkDICOMSequence *op = new vtkDICOMSequence(temp0);

    result = PyVTKSpecialObject_New("vtkDICOMSequence", op);
  }

  return result;
}

static PyObject *
PyvtkDICOMSequence_vtkDICOMSequence_s3(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkDICOMSequence");

  vtkDICOMSequence *temp0 = nullptr;
  PyObject *pobj0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkDICOMSequence"))
  {
    vtkDICOMSequence *op = new vtkDICOMSequence(*temp0);

    result = PyVTKSpecialObject_New("vtkDICOMSequence", op);
  }

  Py_XDECREF(pobj0);

  return result;
}

static PyObject *
PyvtkDICOMSequence_vtkDICOMSequence_s4(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkDICOMSequence");

  vtkDICOMValue *temp0 = nullptr;
  PyObject *pobj0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkDICOMValue"))
  {
    vtkDICOMSequence *op = new vtkDICOMSequence(*temp0);

    result = PyVTKSpecialObject_New("vtkDICOMSequence", op);
  }

  Py_XDECREF(pobj0);

  return result;
}

static PyMethodDef PyvtkDICOMSequence_vtkDICOMSequence_Methods[] = {
  {nullptr, PyvtkDICOMSequence_vtkDICOMSequence_s2, METH_VARARGS,
   "-@I"},
  {nullptr, PyvtkDICOMSequence_vtkDICOMSequence_s3, METH_VARARGS,
   "@W vtkDICOMSequence"},
  {nullptr, PyvtkDICOMSequence_vtkDICOMSequence_s4, METH_VARARGS,
   "@W vtkDICOMValue"},
  {nullptr, nullptr, 0, nullptr}
};

static PyObject *
PyvtkDICOMSequence_vtkDICOMSequence(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkDICOMSequence_vtkDICOMSequence_Methods;
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
  {
    case 0:
      return PyvtkDICOMSequence_vtkDICOMSequence_s1(self, args);
    case 1:
      return vtkPythonOverload::CallMethod(methods, self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "vtkDICOMSequence");
  return nullptr;
}


static PyObject *
PyvtkDICOMSequence_New(PyTypeObject *, PyObject *args, PyObject *kwds)
{
  if (kwds && PyDict_Size(kwds))
  {
    PyErr_SetString(PyExc_TypeError,
                    "this function takes no keyword arguments");
    return nullptr;
  }

  return PyvtkDICOMSequence_vtkDICOMSequence(nullptr, args);
}

static void PyvtkDICOMSequence_Delete(PyObject *self)
{
  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;
  delete static_cast<vtkDICOMSequence *>(obj->vtk_ptr);
  PyObject_Del(self);
}

static PyObject *PyvtkDICOMSequence_String(PyObject *self)
{
  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;
  std::ostringstream os;
  if (obj->vtk_ptr)
  {
    os << *static_cast<const vtkDICOMSequence *>(obj->vtk_ptr);
  }
  const std::string &s = os.str();
  return PyString_FromStringAndSize(s.data(), s.size());
}

static Py_hash_t PyvtkDICOMSequence_Hash(PyObject *self)
{
#if PY_VERSION_HEX >= 0x020600B2
  return PyObject_HashNotImplemented(self);
#else
  char text[256];
  sprintf(text, "unhashable type: '%s'", Py_TYPE(self)->tp_name);
  PyErr_SetString(PyExc_TypeError, text);
  return -1;
#endif
}

static PyTypeObject PyvtkDICOMSequence_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkDICOM.vtkDICOMSequence", // tp_name
  sizeof(PyVTKSpecialObject), // tp_basicsize
  0, // tp_itemsize
  PyvtkDICOMSequence_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKSpecialObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  PyvtkDICOMSequence_Hash, // tp_hash
  nullptr, // tp_call
  PyvtkDICOMSequence_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  nullptr, // tp_setattro
  nullptr, // tp_as_buffer
  Py_TPFLAGS_DEFAULT, // tp_flags
  PyvtkDICOMSequence_Doc, // tp_doc
  nullptr, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  0, // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  nullptr, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  0, // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyvtkDICOMSequence_New, // tp_new
  PyObject_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static void *PyvtkDICOMSequence_CCopy(const void *obj)
{
  if (obj)
  {
    return new vtkDICOMSequence(*static_cast<const vtkDICOMSequence*>(obj));
  }
  return 0;
}

extern "C" { PyObject *PyvtkDICOMSequence_TypeNew(); }

PyObject *PyvtkDICOMSequence_TypeNew()
{
  PyTypeObject *pytype = PyVTKSpecialType_Add(
    &PyvtkDICOMSequence_Type,
    PyvtkDICOMSequence_Methods,
    PyvtkDICOMSequence_vtkDICOMSequence_Methods,
    &PyvtkDICOMSequence_CCopy);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkDICOMSequence(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkDICOMSequence_TypeNew();

  if (o && PyDict_SetItemString(dict, "vtkDICOMSequence", o) != 0)
  {
    Py_DECREF(o);
  }

}

